@@ -6,32 +6,38 @@
 from __future__ import annotations
 
 import glob
-import optparse     # pylint: disable=deprecated-module
+import optparse
 import os
 import os.path
 import shlex
+import signal
 import sys
 import textwrap
 import traceback
-
-from typing import cast, Any, List, NoReturn, Optional, Tuple
+import types
+from typing import Any, NoReturn, cast
 
 import coverage
-from coverage import Coverage
-from coverage import env
-from coverage.collector import HAS_CTRACER
+from coverage import Coverage, env
 from coverage.config import CoverageConfig
 from coverage.control import DEFAULT_DATAFILE
+from coverage.core import CTRACER_FILE
 from coverage.data import combinable_files, debug_data_file
 from coverage.debug import info_header, short_stack, write_formatted_info
-from coverage.exceptions import _BaseCoverageException, _ExceptionDuringRun, NoSource
+from coverage.exceptions import NoSource, _BaseCoverageException, _ExceptionDuringRun
 from coverage.execfile import PyRunner
-from coverage.results import Numbers, should_fail_under
+from coverage.results import display_covered, should_fail_under
 from coverage.version import __url__
 
 # When adding to this file, alphabetization is important.  Look for
 # "alphabetize" comments throughout.
 
+
+def oneline(text: str) -> str:
+    """Turn a multi-line string into one line for help to reformat nicely."""
+    return " ".join(text.split())
+
+
 class Opts:
     """A namespace class for individual options we'll build parsers from."""
 
@@ -39,195 +45,324 @@ class Opts:
     # appears on the command line.
 
     append = optparse.make_option(
-        "-a", "--append", action="store_true",
-        help="Append coverage data to .coverage, otherwise it starts clean each time.",
+        "-a",
+        "--append",
+        action="store_true",
+        help="Append data to the data file. Otherwise it starts clean each time.",
     )
     branch = optparse.make_option(
-        "", "--branch", action="store_true",
+        "",
+        "--branch",
+        action="store_true",
         help="Measure branch coverage in addition to statement coverage.",
     )
     concurrency = optparse.make_option(
-        "", "--concurrency", action="store", metavar="LIBS",
-        help=(
-            "Properly measure code using a concurrency library. " +
-            "Valid values are: {}, or a comma-list of them."
+        "",
+        "--concurrency",
+        action="store",
+        metavar="LIBS",
+        help=oneline(
+            """
+            Properly measure code using a concurrency library.
+            Valid values are: {}, or a comma-list of them.
+            """
         ).format(", ".join(sorted(CoverageConfig.CONCURRENCY_CHOICES))),
     )
     context = optparse.make_option(
-        "", "--context", action="store", metavar="LABEL",
+        "",
+        "--context",
+        action="store",
+        metavar="LABEL",
         help="The context label to record for this coverage run.",
     )
     contexts = optparse.make_option(
-        "", "--contexts", action="store", metavar="REGEX1,REGEX2,...",
-        help=(
-            "Only display data from lines covered in the given contexts. " +
-            "Accepts Python regexes, which must be quoted."
+        "",
+        "--contexts",
+        action="store",
+        metavar="REGEX1,REGEX2,...",
+        help=oneline(
+            """
+            Only display data from lines covered in the given contexts.
+            Accepts Python regexes, which must be quoted.
+            """
         ),
     )
     datafile = optparse.make_option(
-        "", "--data-file", action="store", metavar="DATAFILE",
-        help=(
-            "Base name of the data files to operate on. " +
-            "Defaults to '.coverage'. [env: COVERAGE_FILE]"
+        "",
+        "--data-file",
+        action="store",
+        metavar="DATAFILE",
+        help=oneline(
+            """
+            Base name of the data files to operate on.
+            Defaults to '.coverage'. [env: COVERAGE_FILE]
+            """
         ),
     )
     datafle_input = optparse.make_option(
-        "", "--data-file", action="store", metavar="INFILE",
-        help=(
-            "Read coverage data for report generation from this file. " +
-            "Defaults to '.coverage'. [env: COVERAGE_FILE]"
+        "",
+        "--data-file",
+        action="store",
+        metavar="INFILE",
+        help=oneline(
+            """
+            Read coverage data for report generation from this file.
+            Defaults to '.coverage'. [env: COVERAGE_FILE]
+            """
         ),
     )
     datafile_output = optparse.make_option(
-        "", "--data-file", action="store", metavar="OUTFILE",
-        help=(
-            "Write the recorded coverage data to this file. " +
-            "Defaults to '.coverage'. [env: COVERAGE_FILE]"
+        "",
+        "--data-file",
+        action="store",
+        metavar="OUTFILE",
+        help=oneline(
+            """
+            Write the recorded coverage data to this file.
+            Defaults to '.coverage'. [env: COVERAGE_FILE]
+            """
         ),
     )
     debug = optparse.make_option(
-        "", "--debug", action="store", metavar="OPTS",
+        "",
+        "--debug",
+        action="store",
+        metavar="OPTS",
         help="Debug options, separated by commas. [env: COVERAGE_DEBUG]",
     )
     directory = optparse.make_option(
-        "-d", "--directory", action="store", metavar="DIR",
+        "-d",
+        "--directory",
+        action="store",
+        metavar="DIR",
         help="Write the output files to DIR.",
     )
     fail_under = optparse.make_option(
-        "", "--fail-under", action="store", metavar="MIN", type="float",
+        "",
+        "--fail-under",
+        action="store",
+        metavar="MIN",
+        type="float",
         help="Exit with a status of 2 if the total coverage is less than MIN.",
     )
     format = optparse.make_option(
-        "", "--format", action="store", metavar="FORMAT",
+        "",
+        "--format",
+        action="store",
+        metavar="FORMAT",
         help="Output format, either text (default), markdown, or total.",
     )
     help = optparse.make_option(
-        "-h", "--help", action="store_true",
+        "-h",
+        "--help",
+        action="store_true",
         help="Get help on this command.",
     )
     ignore_errors = optparse.make_option(
-        "-i", "--ignore-errors", action="store_true",
+        "-i",
+        "--ignore-errors",
+        action="store_true",
         help="Ignore errors while reading source files.",
     )
     include = optparse.make_option(
-        "", "--include", action="store", metavar="PAT1,PAT2,...",
-        help=(
-            "Include only files whose paths match one of these patterns. " +
-            "Accepts shell-style wildcards, which must be quoted."
+        "",
+        "--include",
+        action="store",
+        metavar="PAT1,PAT2,...",
+        help=oneline(
+            """
+            Include only files whose paths match one of these patterns.
+            Accepts shell-style wildcards, which must be quoted.
+            """
         ),
     )
     keep = optparse.make_option(
-        "", "--keep", action="store_true",
+        "",
+        "--keep",
+        action="store_true",
         help="Keep original coverage files, otherwise they are deleted.",
     )
     pylib = optparse.make_option(
-        "-L", "--pylib", action="store_true",
-        help=(
-            "Measure coverage even inside the Python installed library, " +
-            "which isn't done by default."
+        "-L",
+        "--pylib",
+        action="store_true",
+        help=oneline(
+            """
+            Measure coverage even inside the Python installed library,
+            which isn't done by default.
+            """
         ),
     )
     show_missing = optparse.make_option(
-        "-m", "--show-missing", action="store_true",
+        "-m",
+        "--show-missing",
+        action="store_true",
         help="Show line numbers of statements in each module that weren't executed.",
     )
     module = optparse.make_option(
-        "-m", "--module", action="store_true",
-        help=(
-            "<pyfile> is an importable Python module, not a script path, " +
-            "to be run as 'python -m' would run it."
+        "-m",
+        "--module",
+        action="store_true",
+        help=oneline(
+            """
+            <pyfile> is an importable Python module, not a script path,
+            to be run as 'python -m' would run it.
+            """
         ),
     )
     omit = optparse.make_option(
-        "", "--omit", action="store", metavar="PAT1,PAT2,...",
-        help=(
-            "Omit files whose paths match one of these patterns. " +
-            "Accepts shell-style wildcards, which must be quoted."
+        "",
+        "--omit",
+        action="store",
+        metavar="PAT1,PAT2,...",
+        help=oneline(
+            """
+            Omit files whose paths match one of these patterns.
+            Accepts shell-style wildcards, which must be quoted.
+            """
         ),
     )
     output_xml = optparse.make_option(
-        "-o", "", action="store", dest="outfile", metavar="OUTFILE",
+        "-o",
+        "",
+        action="store",
+        dest="outfile",
+        metavar="OUTFILE",
         help="Write the XML report to this file. Defaults to 'coverage.xml'",
     )
     output_json = optparse.make_option(
-        "-o", "", action="store", dest="outfile", metavar="OUTFILE",
+        "-o",
+        "",
+        action="store",
+        dest="outfile",
+        metavar="OUTFILE",
         help="Write the JSON report to this file. Defaults to 'coverage.json'",
     )
     output_lcov = optparse.make_option(
-        "-o", "", action="store", dest="outfile", metavar="OUTFILE",
+        "-o",
+        "",
+        action="store",
+        dest="outfile",
+        metavar="OUTFILE",
         help="Write the LCOV report to this file. Defaults to 'coverage.lcov'",
     )
     json_pretty_print = optparse.make_option(
-        "", "--pretty-print", action="store_true",
+        "",
+        "--pretty-print",
+        action="store_true",
         help="Format the JSON for human readers.",
     )
     parallel_mode = optparse.make_option(
-        "-p", "--parallel-mode", action="store_true",
-        help=(
-            "Append the machine name, process id and random number to the " +
-            "data file name to simplify collecting data from " +
-            "many processes."
+        "-p",
+        "--parallel-mode",
+        action="store_true",
+        help=oneline(
+            """
+            Append a unique suffix to the data file name to collect separate
+            data from multiple processes.
+            """
         ),
     )
     precision = optparse.make_option(
-        "", "--precision", action="store", metavar="N", type=int,
-        help=(
-            "Number of digits after the decimal point to display for " +
-            "reported coverage percentages."
+        "",
+        "--precision",
+        action="store",
+        metavar="N",
+        type=int,
+        help=oneline(
+            """
+            Number of digits after the decimal point to display for
+            reported coverage percentages.
+            """
         ),
     )
     quiet = optparse.make_option(
-        "-q", "--quiet", action="store_true",
+        "-q",
+        "--quiet",
+        action="store_true",
         help="Don't print messages about what is happening.",
     )
     rcfile = optparse.make_option(
-        "", "--rcfile", action="store",
-        help=(
-            "Specify configuration file. " +
-            "By default '.coveragerc', 'setup.cfg', 'tox.ini', and " +
-            "'pyproject.toml' are tried. [env: COVERAGE_RCFILE]"
+        "",
+        "--rcfile",
+        action="store",
+        help=oneline(
+            """
+            Specify configuration file.
+            By default '.coveragerc', 'setup.cfg', 'tox.ini', and
+            'pyproject.toml' are tried. [env: COVERAGE_RCFILE]
+            """
+        ),
+    )
+    save_signal = optparse.make_option(
+        "",
+        "--save-signal",
+        action="store",
+        metavar="SIGNAL",
+        choices=["USR1", "USR2"],
+        help=oneline(
+            """
+            Specify a signal that will trigger coverage to write its collected data.
+            Supported values are: USR1, USR2. Not available on Windows.
+            """
         ),
     )
     show_contexts = optparse.make_option(
-        "--show-contexts", action="store_true",
+        "--show-contexts",
+        action="store_true",
         help="Show contexts for covered lines.",
     )
     skip_covered = optparse.make_option(
-        "--skip-covered", action="store_true",
+        "--skip-covered",
+        action="store_true",
         help="Skip files with 100% coverage.",
     )
     no_skip_covered = optparse.make_option(
-        "--no-skip-covered", action="store_false", dest="skip_covered",
+        "--no-skip-covered",
+        action="store_false",
+        dest="skip_covered",
         help="Disable --skip-covered.",
     )
     skip_empty = optparse.make_option(
-        "--skip-empty", action="store_true",
+        "--skip-empty",
+        action="store_true",
         help="Skip files with no code.",
     )
     sort = optparse.make_option(
-        "--sort", action="store", metavar="COLUMN",
-        help=(
-            "Sort the report by the named column: name, stmts, miss, branch, brpart, or cover. " +
-             "Default is name."
+        "--sort",
+        action="store",
+        metavar="COLUMN",
+        help=oneline(
+            """
+            Sort the report by the named column: name, stmts, miss, branch, brpart, or cover.
+            Default is name.
+            """
         ),
     )
     source = optparse.make_option(
-        "", "--source", action="store", metavar="SRC1,SRC2,...",
+        "",
+        "--source",
+        action="store",
+        metavar="SRC1,SRC2,...",
         help="A list of directories or importable names of code to measure.",
     )
     timid = optparse.make_option(
-        "", "--timid", action="store_true",
-        help=(
-            "Use a simpler but slower trace method. Try this if you get " +
-            "seemingly impossible results!"
-        ),
+        "",
+        "--timid",
+        action="store_true",
+        help="Use the slower Python trace function core.",
     )
     title = optparse.make_option(
-        "", "--title", action="store", metavar="TITLE",
+        "",
+        "--title",
+        action="store",
+        metavar="TITLE",
         help="A text string to use as the title on the HTML.",
     )
     version = optparse.make_option(
-        "", "--version", action="store_true",
+        "",
+        "--version",
+        action="store_true",
         help="Display version information and exit.",
     )
 
@@ -267,6 +402,7 @@ class CoverageOptionParser(optparse.OptionParser):
             pylib=None,
             quiet=None,
             rcfile=True,
+            save_signal=None,
             show_contexts=None,
             show_missing=None,
             skip_covered=None,
@@ -282,9 +418,10 @@ class CoverageOptionParser(optparse.OptionParser):
 
     class OptionParserError(Exception):
         """Used to stop the optparse error handler ending the process."""
+
         pass
 
-    def parse_args_ok(self, args: List[str]) -> Tuple[bool, Optional[optparse.Values], List[str]]:
+    def parse_args_ok(self, args: list[str]) -> tuple[bool, optparse.Values | None, list[str]]:
         """Call optparse.parse_args, but return a triple:
 
         (ok, options, args)
@@ -308,10 +445,12 @@ class GlobalOptionParser(CoverageOptionParser):
     def __init__(self) -> None:
         super().__init__()
 
-        self.add_options([
-            Opts.help,
-            Opts.version,
-        ])
+        self.add_options(
+            [
+                Opts.help,
+                Opts.version,
+            ]
+        )
 
 
 class CmdOptionParser(CoverageOptionParser):
@@ -320,9 +459,9 @@ class CmdOptionParser(CoverageOptionParser):
     def __init__(
         self,
         action: str,
-        options: List[optparse.Option],
+        options: list[optparse.Option],
         description: str,
-        usage: Optional[str] = None,
+        usage: str | None = None,
     ):
         """Create an OptionParser for a coverage.py command.
 
@@ -342,12 +481,12 @@ class CmdOptionParser(CoverageOptionParser):
         self.add_options(options)
         self.cmd = action
 
-    def __eq__(self, other: str) -> bool:       # type: ignore[override]
+    def __eq__(self, other: str) -> bool:  # type: ignore[override]
         # A convenience equality, so that I can put strings in unit test
         # results, and they will compare equal to objects.
-        return (other == f"<CmdOptionParser:{self.cmd}>")
+        return other == f"<CmdOptionParser:{self.cmd}>"
 
-    __hash__ = None         # type: ignore[assignment]
+    __hash__ = None  # type: ignore[assignment]
 
     def get_prog_name(self) -> str:
         """Override of an undocumented function in optparse.OptionParser."""
@@ -356,6 +495,7 @@ class CmdOptionParser(CoverageOptionParser):
         # Include the sub-command for this parser as part of the command.
         return f"{program_name} {self.cmd}"
 
+
 # In lists of Opts, keep them alphabetized by the option names as they appear
 # on the command line, since these lists determine the order of the options in
 # the help output.
@@ -377,14 +517,16 @@ COMMANDS = {
             Opts.ignore_errors,
             Opts.include,
             Opts.omit,
-            ] + GLOBAL_ARGS,
+        ]
+        + GLOBAL_ARGS,
         usage="[options] [modules]",
-        description=(
-            "Make annotated copies of the given files, marking statements that are executed " +
-            "with > and statements that are missed with !."
+        description=oneline(
+            """
+            Make annotated copies of the given files, marking statements that are executed
+            with > and statements that are missed with !.
+            """
         ),
     ),
-
     "combine": CmdOptionParser(
         "combine",
         [
@@ -392,47 +534,51 @@ COMMANDS = {
             Opts.datafile,
             Opts.keep,
             Opts.quiet,
-            ] + GLOBAL_ARGS,
+        ]
+        + GLOBAL_ARGS,
         usage="[options] <path1> <path2> ... <pathN>",
-        description=(
-            "Combine data from multiple coverage files. " +
-            "The combined results are written to a single " +
-            "file representing the union of the data. The positional " +
-            "arguments are data files or directories containing data files. " +
-            "If no paths are provided, data files in the default data file's " +
-            "directory are combined."
+        description=oneline(
+            """
+            Combine data from multiple coverage files.
+            The combined results are written to a single
+            file representing the union of the data. The positional
+            arguments are data files or directories containing data files.
+            If no paths are provided, data files in the default data file's
+            directory are combined.
+            """
         ),
     ),
-
     "debug": CmdOptionParser(
-        "debug", GLOBAL_ARGS,
+        "debug",
+        GLOBAL_ARGS,
         usage="<topic>",
-        description=(
-            "Display information about the internals of coverage.py, " +
-            "for diagnosing problems. " +
-            "Topics are: " +
-                "'data' to show a summary of the collected data; " +
-                "'sys' to show installation information; " +
-                "'config' to show the configuration; " +
-                "'premain' to show what is calling coverage; " +
-                "'pybehave' to show internal flags describing Python behavior."
+        description=oneline(
+            """
+            Display information about the internals of coverage.py,
+            for diagnosing problems.
+            Topics are:
+                'data' to show a summary of the collected data;
+                'sys' to show installation information;
+                'config' to show the configuration;
+                'premain' to show what is calling coverage;
+                'pybehave' to show internal flags describing Python behavior.
+            """
         ),
     ),
-
     "erase": CmdOptionParser(
         "erase",
         [
-            Opts.datafile
-            ] + GLOBAL_ARGS,
+            Opts.datafile,
+        ]
+        + GLOBAL_ARGS,
         description="Erase previously collected coverage data.",
     ),
-
     "help": CmdOptionParser(
-        "help", GLOBAL_ARGS,
+        "help",
+        GLOBAL_ARGS,
         usage="[command]",
         description="Describe how to use coverage.py",
     ),
-
     "html": CmdOptionParser(
         "html",
         [
@@ -450,15 +596,17 @@ COMMANDS = {
             Opts.no_skip_covered,
             Opts.skip_empty,
             Opts.title,
-            ] + GLOBAL_ARGS,
+        ]
+        + GLOBAL_ARGS,
         usage="[options] [modules]",
-        description=(
-            "Create an HTML report of the coverage of the files.  " +
-            "Each file gets its own page, with the source decorated to show " +
-            "executed, excluded, and missed lines."
+        description=oneline(
+            """
+            Create an HTML report of the coverage of the files.
+            Each file gets its own page, with the source decorated to show
+            executed, excluded, and missed lines.
+            """
         ),
     ),
-
     "json": CmdOptionParser(
         "json",
         [
@@ -472,11 +620,11 @@ COMMANDS = {
             Opts.json_pretty_print,
             Opts.quiet,
             Opts.show_contexts,
-            ] + GLOBAL_ARGS,
+        ]
+        + GLOBAL_ARGS,
         usage="[options] [modules]",
         description="Generate a JSON report of coverage results.",
     ),
-
     "lcov": CmdOptionParser(
         "lcov",
         [
@@ -487,11 +635,11 @@ COMMANDS = {
             Opts.output_lcov,
             Opts.omit,
             Opts.quiet,
-            ] + GLOBAL_ARGS,
+        ]
+        + GLOBAL_ARGS,
         usage="[options] [modules]",
         description="Generate an LCOV report of coverage results.",
     ),
-
     "report": CmdOptionParser(
         "report",
         [
@@ -508,11 +656,11 @@ COMMANDS = {
             Opts.skip_covered,
             Opts.no_skip_covered,
             Opts.skip_empty,
-            ] + GLOBAL_ARGS,
+        ]
+        + GLOBAL_ARGS,
         usage="[options] [modules]",
         description="Report coverage statistics on modules.",
     ),
-
     "run": CmdOptionParser(
         "run",
         [
@@ -526,13 +674,14 @@ COMMANDS = {
             Opts.omit,
             Opts.pylib,
             Opts.parallel_mode,
+            Opts.save_signal,
             Opts.source,
             Opts.timid,
-            ] + GLOBAL_ARGS,
+        ]
+        + GLOBAL_ARGS,
         usage="[options] <pyfile> [program options]",
         description="Run a Python program, measuring code execution.",
     ),
-
     "xml": CmdOptionParser(
         "xml",
         [
@@ -544,7 +693,8 @@ COMMANDS = {
             Opts.output_xml,
             Opts.quiet,
             Opts.skip_empty,
-            ] + GLOBAL_ARGS,
+        ]
+        + GLOBAL_ARGS,
         usage="[options] [modules]",
         description="Generate an XML report of coverage results.",
     ),
@@ -552,9 +702,9 @@ COMMANDS = {
 
 
 def show_help(
-    error: Optional[str] = None,
-    topic: Optional[str] = None,
-    parser: Optional[optparse.OptionParser] = None,
+    error: str | None = None,
+    topic: str | None = None,
+    parser: optparse.OptionParser | None = None,
 ) -> None:
     """Display an error message, or the named topic."""
     assert error or topic or parser
@@ -572,12 +722,12 @@ def show_help(
         # get back to the original form.
         auto_suffix = "-script.py"
         if program_name.endswith(auto_suffix):
-            program_name = program_name[:-len(auto_suffix)]
+            program_name = program_name[: -len(auto_suffix)]
 
     help_params = dict(coverage.__dict__)
     help_params["__url__"] = __url__
     help_params["program_name"] = program_name
-    if HAS_CTRACER:
+    if CTRACER_FILE:
         help_params["extension_modifier"] = "with C extension"
     else:
         help_params["extension_modifier"] = "without C extension"
@@ -608,7 +758,7 @@ class CoverageScript:
         self.global_option = False
         self.coverage: Coverage
 
-    def command_line(self, argv: List[str]) -> int:
+    def command_line(self, argv: list[str]) -> int:
         """The bulk of the command line interface to coverage.py.
 
         `argv` is the argument list to process.
@@ -623,7 +773,7 @@ class CoverageScript:
 
         # The command syntax we parse depends on the first argument.  Global
         # switch syntax always starts with an option.
-        parser: Optional[optparse.OptionParser]
+        parser: optparse.OptionParser | None
         self.global_option = argv[0].startswith("-")
         if self.global_option:
             parser = GlobalOptionParser()
@@ -715,7 +865,7 @@ class CoverageScript:
                 skip_empty=options.skip_empty,
                 sort=options.sort,
                 output_format=options.format,
-                **report_args
+                **report_args,
             )
         elif options.action == "annotate":
             self.coverage.annotate(directory=options.directory, **report_args)
@@ -727,25 +877,25 @@ class CoverageScript:
                 skip_empty=options.skip_empty,
                 show_contexts=options.show_contexts,
                 title=options.title,
-                **report_args
+                **report_args,
             )
         elif options.action == "xml":
             total = self.coverage.xml_report(
                 outfile=options.outfile,
                 skip_empty=options.skip_empty,
-                **report_args
+                **report_args,
             )
         elif options.action == "json":
             total = self.coverage.json_report(
                 outfile=options.outfile,
                 pretty_print=options.pretty_print,
                 show_contexts=options.show_contexts,
-                **report_args
+                **report_args,
             )
         elif options.action == "lcov":
             total = self.coverage.lcov_report(
                 outfile=options.outfile,
-                **report_args
+                **report_args,
             )
         else:
             # There are no other possible actions.
@@ -763,7 +913,7 @@ class CoverageScript:
             precision = cast(int, self.coverage.get_option("report:precision"))
             if should_fail_under(total, fail_under, precision):
                 msg = "total of {total} is less than fail-under={fail_under:.{p}f}".format(
-                    total=Numbers(precision=precision).display_covered(total),
+                    total=display_covered(total, precision),
                     fail_under=fail_under,
                     p=precision,
                 )
@@ -775,7 +925,7 @@ class CoverageScript:
     def do_help(
         self,
         options: optparse.Values,
-        args: List[str],
+        args: list[str],
         parser: optparse.OptionParser,
     ) -> bool:
         """Deal with help requests.
@@ -810,7 +960,12 @@ class CoverageScript:
 
         return False
 
-    def do_run(self, options: optparse.Values, args: List[str]) -> int:
+    def do_signal_save(self, _signum: int, _frame: types.FrameType | None) -> None:
+        """Signal handler to save coverage report"""
+        print("Saving coverage data...", flush=True)
+        self.coverage.save()
+
+    def do_run(self, options: optparse.Values, args: list[str]) -> int:
         """Implementation of 'coverage run'."""
 
         if not args:
@@ -840,9 +995,9 @@ class CoverageScript:
                 # they will be None if they have not been specified.
                 if getattr(options, opt_name) is not None:
                     show_help(
-                        "Options affecting multiprocessing must only be specified " +
-                        "in a configuration file.\n" +
-                        f"Remove --{opt_name} from the command line."
+                        "Options affecting multiprocessing must only be specified "
+                        + "in a configuration file.\n"
+                        + f"Remove --{opt_name} from the command line.",
                     )
                     return ERR
 
@@ -854,6 +1009,13 @@ class CoverageScript:
         if options.append:
             self.coverage.load()
 
+        if options.save_signal:
+            if env.WINDOWS:
+                show_help("--save-signal is not supported on Windows.")
+                return ERR
+            sig = getattr(signal, f"SIG{options.save_signal}")
+            signal.signal(sig, self.do_signal_save)
+
         # Run the script.
         self.coverage.start()
         code_ran = True
@@ -869,7 +1031,7 @@ class CoverageScript:
 
         return OK
 
-    def do_debug(self, args: List[str]) -> int:
+    def do_debug(self, args: list[str]) -> int:
         """Implementation of 'coverage debug'."""
 
         if not args:
@@ -902,7 +1064,7 @@ class CoverageScript:
         return OK
 
 
-def unshell_list(s: str) -> Optional[List[str]]:
+def unshell_list(s: str) -> list[str] | None:
     """Turn a command-line argument into a list."""
     if not s:
         return None
@@ -916,7 +1078,7 @@ def unshell_list(s: str) -> Optional[List[str]]:
     return s.split(",")
 
 
-def unglob_args(args: List[str]) -> List[str]:
+def unglob_args(args: list[str]) -> list[str]:
     """Interpret shell wildcards for platforms that need it."""
     if env.WINDOWS:
         globbed = []
@@ -951,17 +1113,17 @@ HELP_TOPICS = {
 
         Use "{program_name} help <command>" for detailed help on any command.
     """,
-
-    "minimum_help": (
-        "Code coverage for Python, version {__version__} {extension_modifier}.  " +
-        "Use '{program_name} help' for help."
+    "minimum_help": oneline(
+        """
+        Code coverage for Python, version {__version__} {extension_modifier}.
+        Use '{program_name} help' for help.
+        """
     ),
-
     "version": "Coverage.py, version {__version__} {extension_modifier}",
 }
 
 
-def main(argv: Optional[List[str]] = None) -> Optional[int]:
+def main(argv: list[str] | None = None) -> int | None:
     """The main entry point to coverage.py.
 
     This is installed as the script entry point.
@@ -975,7 +1137,7 @@ def main(argv: Optional[List[str]] = None) -> Optional[int]:
         # An exception was caught while running the product code.  The
         # sys.exc_info() return tuple is packed into an _ExceptionDuringRun
         # exception.
-        traceback.print_exception(*err.args)    # pylint: disable=no-value-for-parameter
+        traceback.print_exception(*err.args)  # pylint: disable=no-value-for-parameter
         status = ERR
     except _BaseCoverageException as err:
         # A controlled error inside coverage.py: print the message to the user.
@@ -990,18 +1152,20 @@ def main(argv: Optional[List[str]] = None) -> Optional[int]:
             status = None
     return status
 
+
 # Profiling using ox_profile.  Install it from GitHub:
 #   pip install git+https://github.com/emin63/ox_profile.git
 #
 # $set_env.py: COVERAGE_PROFILE - Set to use ox_profile.
 _profile = os.getenv("COVERAGE_PROFILE")
-if _profile:                                                # pragma: debugging
-    from ox_profile.core.launchers import SimpleLauncher    # pylint: disable=import-error
+if _profile:  # pragma: debugging
+    from ox_profile.core.launchers import SimpleLauncher  # pylint: disable=import-error
+
     original_main = main
 
-    def main(                                               # pylint: disable=function-redefined
-        argv: Optional[List[str]] = None,
-    ) -> Optional[int]:
+    def main(  # pylint: disable=function-redefined
+        argv: list[str] | None = None,
+    ) -> int | None:
         """A wrapper around main that profiles."""
         profiler = SimpleLauncher.launch()
         try:
