@@ -32,11 +32,11 @@ typedef struct CTracer {
     PyObject * disable_plugin;
 
     /* Has the tracer been started? */
-    BOOL started;
+    _Atomic BOOL started;
     /* Are we tracing arcs, or just lines? */
     BOOL tracing_arcs;
     /* Have we had any activity? */
-    BOOL activity;
+    _Atomic BOOL activity;
     /* The current dynamic context. */
     PyObject * context;
 
