@@ -10,14 +10,14 @@ import os.path
 import sys
 import time
 import xml.dom.minidom
-
+from collections.abc import Iterable
 from dataclasses import dataclass
-from typing import Any, Dict, IO, Iterable, Optional, TYPE_CHECKING, cast
+from typing import IO, TYPE_CHECKING, Any
 
 from coverage import __version__, files
-from coverage.misc import isolate_module, human_sorted, human_sorted_items
+from coverage.misc import human_sorted, human_sorted_items, isolate_module
 from coverage.plugin import FileReporter
-from coverage.report import get_analysis_to_report
+from coverage.report_core import get_analysis_to_report
 from coverage.results import Analysis
 from coverage.types import TMorf
 from coverage.version import __url__
@@ -36,13 +36,14 @@ def rate(hit: int, num: int) -> str:
     if num == 0:
         return "1"
     else:
-        return "%.4g" % (hit / num)
+        return f"{hit / num:.4g}"
 
 
 @dataclass
 class PackageData:
     """Data we keep about each "package" (in Java terms)."""
-    elements: Dict[str, xml.dom.minidom.Element]
+
+    elements: dict[str, xml.dom.minidom.Element]
     hits: int
     lines: int
     br_hits: int
@@ -72,10 +73,10 @@ class XmlReporter:
                     else:
                         src = files.canonical_filename(src)
                     self.source_paths.add(src)
-        self.packages: Dict[str, PackageData] = {}
+        self.packages: dict[str, PackageData] = {}
         self.xml_out: xml.dom.minidom.Document
 
-    def report(self, morfs: Optional[Iterable[TMorf]], outfile: Optional[IO[str]] = None) -> float:
+    def report(self, morfs: Iterable[TMorf] | None, outfile: IO[str] | None = None) -> float:
         """Generate a Cobertura-compatible XML report for `morfs`.
 
         `morfs` is a list of modules or file names.
@@ -94,11 +95,14 @@ class XmlReporter:
 
         # Write header stuff.
         xcoverage = self.xml_out.documentElement
+        assert xcoverage is not None
         xcoverage.setAttribute("version", __version__)
-        xcoverage.setAttribute("timestamp", str(int(time.time()*1000)))
-        xcoverage.appendChild(self.xml_out.createComment(
-            f" Generated by coverage.py: {__url__} "
-        ))
+        xcoverage.setAttribute("timestamp", str(int(time.time() * 1000)))
+        xcoverage.appendChild(
+            self.xml_out.createComment(
+                f" Generated by coverage.py: {__url__} ",
+            )
+        )
         xcoverage.appendChild(self.xml_out.createComment(f" Based on {DTD_URL} "))
 
         # Call xml_file for each file in the data.
@@ -181,14 +185,14 @@ class XmlReporter:
             if not self.config.relative_files:
                 source_path = files.canonical_filename(source_path)
             if filename.startswith(source_path.replace("\\", "/") + "/"):
-                rel_name = filename[len(source_path)+1:]
+                rel_name = filename[len(source_path) + 1 :]
                 break
         else:
             rel_name = fr.relative_filename().replace("\\", "/")
-            self.source_paths.add(fr.filename[:-len(rel_name)].rstrip(r"\/"))
+            self.source_paths.add(fr.filename[: -len(rel_name)].rstrip(r"\/"))
 
         dirname = os.path.dirname(rel_name) or "."
-        dirname = "/".join(dirname.split("/")[:self.config.xml_package_depth])
+        dirname = "/".join(dirname.split("/")[: self.config.xml_package_depth])
         package_name = dirname.replace("/", ".")
 
         package = self.packages.setdefault(package_name, PackageData({}, 0, 0, 0, 0))
@@ -222,7 +226,7 @@ class XmlReporter:
                     xline.setAttribute("branch", "true")
                     xline.setAttribute(
                         "condition-coverage",
-                        "%d%% (%d/%d)" % (100*taken//total, taken, total)
+                        f"{100 * taken // total}% ({taken}/{total})",
                     )
                 if line in missing_branch_arcs:
                     annlines = ["exit" if b < 0 else str(b) for b in missing_branch_arcs[line]]
@@ -257,4 +261,4 @@ class XmlReporter:
 
 def serialize_xml(dom: xml.dom.minidom.Document) -> str:
     """Serialize a minidom node to XML."""
-    return cast(str, dom.toprettyxml())
+    return dom.toprettyxml()
