@@ -16,27 +16,36 @@ class AnnotationGoldTest(CoverageTest):
 
     def make_multi(self) -> None:
         """Make a few source files we need for the tests."""
-        self.make_file("multi.py", """\
+        self.make_file(
+            "multi.py",
+            """\
             import a.a
             import b.b
 
             a.a.a(1)
             b.b.b(2)
-            """)
+            """,
+        )
         self.make_file("a/__init__.py")
-        self.make_file("a/a.py", """\
+        self.make_file(
+            "a/a.py",
+            """\
             def a(x):
                 if x == 1:
                     print("x is 1")
                 else:
                     print("x is not 1")
-            """)
+            """,
+        )
         self.make_file("b/__init__.py")
-        self.make_file("b/b.py", """\
+        self.make_file(
+            "b/b.py",
+            """\
             def b(x):
                 msg = f"x is {x}"
                 print(msg)
-            """)
+            """,
+        )
 
     def test_multi(self) -> None:
         self.make_multi()
@@ -53,19 +62,24 @@ class AnnotationGoldTest(CoverageTest):
         compare(gold_path("annotate/anno_dir"), "out_anno_dir", "*,cover")
 
     def test_encoding(self) -> None:
-        self.make_file("utf8.py", """\
+        self.make_file(
+            "utf8.py",
+            """\
             # -*- coding: utf-8 -*-
             # This comment has an accent: é
 
             print("spam eggs")
-            """)
+            """,
+        )
         cov = coverage.Coverage()
         self.start_import_stop(cov, "utf8")
         cov.annotate()
         compare(gold_path("annotate/encodings"), ".", "*,cover")
 
     def test_white(self) -> None:
-        self.make_file("white.py", """\
+        self.make_file(
+            "white.py",
+            """\
             # A test case sent to me by Steve White
 
             def f(self):
@@ -99,7 +113,8 @@ class AnnotationGoldTest(CoverageTest):
                     a = 2
 
             h(2)
-            """)
+            """,
+        )
 
         cov = coverage.Coverage()
         self.start_import_stop(cov, "white")
@@ -107,7 +122,9 @@ class AnnotationGoldTest(CoverageTest):
         compare(gold_path("annotate/white"), ".", "*,cover")
 
     def test_missing_after_else(self) -> None:
-        self.make_file("mae.py", """\
+        self.make_file(
+            "mae.py",
+            """\
             def f(x):
                 if x == 1:
                     print("1")
@@ -118,7 +135,8 @@ class AnnotationGoldTest(CoverageTest):
                 print("nope")
             if f(2):
                 print("nope")
-            """)
+            """,
+        )
 
         cov = coverage.Coverage()
         self.start_import_stop(cov, "mae")
